/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999-2007 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Activator.java 2951 2008-04-25 09:18:48Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.war.impl.osgi;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.InvalidSyntaxException;
import org.osgi.util.tracker.ServiceTracker;
import org.ow2.util.ee.metadata.war.api.IWarDeployableMetadataFactory;
import org.ow2.util.ee.metadata.war.impl.WarDeployableMetadataFactory;
import org.ow2.util.scan.api.IArchiveScannerFactory;

/**
 * Activator which add war deployable metadata factory to DeployableMetadataManager.
 * @author Gael Lalire
 */
public class Activator implements BundleActivator {

    /**
     * Called when this bundle is started so the Framework can perform the
     * bundle-specific activities necessary to start this bundle. This method
     * can be used to register services or to allocate any resources that this
     * bundle needs.
     * @param context The execution context of the bundle being started.
     */
    public void start(final BundleContext bc) {
        try {
            ServiceTracker serviceTracker = new ServiceTracker(bc, bc.createFilter("(objectClass=" + IArchiveScannerFactory.class.getName() + ")"), null);
            serviceTracker.open();
            IArchiveScannerFactory archiveScannerFactory = (IArchiveScannerFactory) serviceTracker.getService();
            bc.registerService(IWarDeployableMetadataFactory.class.getName(), new WarDeployableMetadataFactory(archiveScannerFactory), null);
        } catch (InvalidSyntaxException e) {
            e.printStackTrace();
        }
    }

    /**
     * Called when this bundle is stopped so the Framework can perform the
     * bundle-specific activities necessary to stop the bundle.
     * @param context The execution context of the bundle being stopped.
     */
    public void stop(final BundleContext bc) {
        // Do nothing
    }

}
